box - GooeyPy Docs

Documentation
Overview
gui

- app
- widget
- styleset
- effects

widgets

- label
- button
- input
- slider
- container
- box
- selectbox
- textblock
- image

- VBox
- VBox.add
- HBox
- HBox.add

# VBox

VBox([expand]) -> VBox widget

A box to automatically position widgets vertically.

### Arguments

expand
  If set to True (default) all widgets will expand to be the same width.

## VBox.add

VBox.add(widgets) -> None

Add widgets to Container.

### Arguments

widgets
  can ether be a single widget or a list of widgets.

# HBox

HBox([expand]) -> HBox widget

A box to automatically position widgets horizontally.

### Arguments

expand
  If set to True (default) all widgets will expand to be the same height.

## HBox.add

VBox.add(widgets) -> None

Add widgets to Container.

### Arguments

widgets
  can ether be a single widget or a list of widgets.